==> bibledit-0.4.tar.gz: bibledit-0.4/src/track.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_TRACK_H
#define INCLUDED_TRACK_H

#include "libraries.h"


class Track {
 public:
  Track (unsigned int dummy);
  ~Track ();
  void tick(const string& book, const string& chapter, const string& verse);
  void get_next_reference (string& book, string& chapter, string& verse, bool next);
  bool next_reference_available();
  bool previous_reference_available();
  void clear();
 private:
  unsigned int time_elapsed;
  string previous_reference;
  vector<string> recorded_books;
  vector<string> recorded_chapters;
  vector<string> recorded_verses;
  int reference_pointer;
  string reference (const string& book, const string& chapter, const string& verse);
  /* IMPORTANT When adding new variables, get them cleared in function clear() */
};


#endif

==> bibledit-0.5.tar.gz: bibledit-0.5/src/track.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_TRACK_H
#define INCLUDED_TRACK_H

#include "libraries.h"


class Track
{
public:
  Track (unsigned int dummy);
   ~Track ();
  void tick (const string & book, const string & chapter,
             const string & verse);
  void get_next_reference (string & book, string & chapter, string & verse,
                           bool next);
  bool next_reference_available ();
  bool previous_reference_available ();
  void clear ();
private:
  unsigned int time_elapsed;
  string previous_reference;
    vector < string > recorded_books;
    vector < string > recorded_chapters;
    vector < string > recorded_verses;
  int reference_pointer;
  string reference (const string & book, const string & chapter,
                    const string & verse);
  /* IMPORTANT When adding new variables, get them cleared in function clear() */
};


#endif
